@@ -1,28 +1,14 @@
-import json
 import typing
+from json import loads as json_loads
 
+import xpresso.binders._body.discriminated as discriminated
+import xpresso.binders._body.files as files
+import xpresso.binders._body.forms as forms
+import xpresso.binders._body.json as json
 import xpresso.binders.dependants as param_dependants
 import xpresso.openapi.models as openapi_models
 from xpresso._utils.compat import Annotated, Literal
-from xpresso.binders._body.extractors.discriminated import (
-    ContentTypeDiscriminatedExtractorMarker,
-)
-from xpresso.binders._body.extractors.file import FileBodyExtractorMarker
-from xpresso.binders._body.extractors.form import FormDataBodyExtractorMarker
-from xpresso.binders._body.extractors.form_encoded_field import (
-    FormEncodedFieldExtractorMarker,
-)
-from xpresso.binders._body.extractors.form_field_extractor import FieldExtractorMarker
-from xpresso.binders._body.extractors.json import Decoder, JsonBodyExtractorMarker
 from xpresso.binders._body.form_field import FormFieldMarker
-from xpresso.binders._body.openapi.discriminated import (
-    OpenAPIContentTypeDiscriminatedMarker,
-)
-from xpresso.binders._body.openapi.file import OpenAPIFileMarker
-from xpresso.binders._body.openapi.form import OpenAPIFormDataMarker
-from xpresso.binders._body.openapi.form_encoded_field import OpenAPIFormFieldMarker
-from xpresso.binders._body.openapi.form_field_extractor import OpenAPIFieldMarker
-from xpresso.binders._body.openapi.json import OpenAPIJsonMarker
 
 Example = typing.Union[openapi_models.Example, typing.Any]
 
@@ -31,24 +17,28 @@ def Json(
     *,
     examples: typing.Optional[typing.Dict[str, Example]] = None,
     description: typing.Optional[str] = None,
-    decoder: Decoder = json.loads,
+    decoder: json.SupportsJsonDecoder = json_loads,
     enforce_media_type: bool = True,
     consume: bool = True,
     include_in_schema: bool = True,
 ) -> param_dependants.BodyBinderMarker:
-    extractor = JsonBodyExtractorMarker(
+    body_extractor_marker = json.BodyExtractorMarker(
         decoder=decoder,
         enforce_media_type=enforce_media_type,
         consume=consume,
     )
-    openapi = OpenAPIJsonMarker(
+    field_extractor_marker = json.FieldExtractorMarker(decoder=decoder)
+    body_openapi_marker = json.BodyOpenAPIMarker(
         description=description,
         examples=examples,
         include_in_schema=include_in_schema,
     )
+    openapi_field_marker = json.FieldOpenAPIMarker()
     return param_dependants.BodyBinderMarker(
-        extractor_marker=extractor,
-        openapi_marker=openapi,
+        extractor_marker=body_extractor_marker,
+        field_extractor_marker=field_extractor_marker,
+        openapi_marker=body_openapi_marker,
+        openapi_field_marker=openapi_field_marker,
     )
 
 
@@ -62,21 +52,28 @@ def File(
     consume: bool = True,
     include_in_schema: bool = True,
 ) -> param_dependants.BodyBinderMarker:
-    extractor = FileBodyExtractorMarker(
+    body_extractor = files.BodyExtractorMarker(
         media_type=media_type,
         enforce_media_type=enforce_media_type,
         consume=consume,
     )
-    openapi = OpenAPIFileMarker(
+    field_extractor_marker = files.FieldExtractorMarker()
+    openapi_body_marker = files.BodyOpenAPIMarker(
         description=description,
         examples=examples,
         media_type=media_type,
         format=format,
         include_in_schema=include_in_schema,
     )
+    openapi_field_marker = files.FieldOpenAPIMarker(
+        media_type=media_type,
+        format=format,
+    )
     return param_dependants.BodyBinderMarker(
-        extractor_marker=extractor,
-        openapi_marker=openapi,
+        extractor_marker=body_extractor,
+        field_extractor_marker=field_extractor_marker,
+        openapi_marker=openapi_body_marker,
+        openapi_field_marker=openapi_field_marker,
     )
 
 
@@ -87,20 +84,20 @@ def FormEncodedField(
     explode: bool = True,
     include_in_schema: bool = True,
 ) -> FormFieldMarker:
-    extractor = FormEncodedFieldExtractorMarker(
+    extractor_marker = forms.FormEncodedFieldExtractorMarker(
         alias=alias,
         style=style,
         explode=explode,
     )
-    openapi = OpenAPIFormFieldMarker(
+    openapi_marker = forms.FormEncodedOpenAPIMarker(
         alias=alias,
         style=style,
         explode=explode,
         include_in_schema=include_in_schema,
     )
     return FormFieldMarker(
-        extractor_marker=extractor,
-        openapi_marker=openapi,
+        extractor_marker=extractor_marker,
+        openapi_marker=openapi_marker,
     )
 
 
@@ -109,8 +106,8 @@ def FormField(
     alias: typing.Optional[str] = None,
     include_in_schema: bool = True,
 ) -> FormFieldMarker:
-    extractor = FieldExtractorMarker(alias=alias, repeated=False)
-    openapi = OpenAPIFieldMarker(
+    extractor = forms.FieldExtractorMarker(alias=alias, repeated=False)
+    openapi = forms.FieldOpenAPIMarker(
         alias=alias,
         include_in_schema=include_in_schema,
         repeated=False,
@@ -126,8 +123,8 @@ def RepeatedFormField(
     alias: typing.Optional[str] = None,
     include_in_schema: bool = True,
 ) -> FormFieldMarker:
-    extractor = FieldExtractorMarker(alias=alias, repeated=True)
-    openapi = OpenAPIFieldMarker(
+    extractor = forms.FieldExtractorMarker(alias=alias, repeated=True)
+    openapi = forms.FieldOpenAPIMarker(
         alias=alias,
         include_in_schema=include_in_schema,
         repeated=True,
@@ -145,19 +142,21 @@ def Form(
     description: typing.Optional[str] = None,
     include_in_schema: bool = True,
 ) -> param_dependants.BodyBinderMarker:
-    extractor = FormDataBodyExtractorMarker(
+    body_extractor_marker = forms.BodyExtractorMarker(
         media_type="application/x-www-form-urlencoded",
         enforce_media_type=enforce_media_type,
     )
-    openapi = OpenAPIFormDataMarker(
+    body_openapi_marker = forms.BodyOpenAPIMarker(
         description=description,
         examples=examples,
         media_type="application/x-www-form-urlencoded",
         include_in_schema=include_in_schema,
     )
     return param_dependants.BodyBinderMarker(
-        extractor_marker=extractor,
-        openapi_marker=openapi,
+        extractor_marker=body_extractor_marker,
+        field_extractor_marker=None,
+        openapi_marker=body_openapi_marker,
+        openapi_field_marker=None,
     )
 
 
@@ -168,19 +167,21 @@ def Multipart(
     description: typing.Optional[str] = None,
     include_in_schema: bool = True,
 ) -> param_dependants.BodyBinderMarker:
-    extractor = FormDataBodyExtractorMarker(
+    body_extractor_marker = forms.BodyExtractorMarker(
         media_type="multipart/form-data",
         enforce_media_type=enforce_media_type,
     )
-    openapi = OpenAPIFormDataMarker(
+    body_openapi_marker = forms.BodyOpenAPIMarker(
         description=description,
         examples=examples,
         media_type="multipart/form-data",
         include_in_schema=include_in_schema,
     )
     return param_dependants.BodyBinderMarker(
-        extractor_marker=extractor,
-        openapi_marker=openapi,
+        extractor_marker=body_extractor_marker,
+        field_extractor_marker=None,
+        openapi_marker=body_openapi_marker,
+        openapi_field_marker=None,
     )
 
 
@@ -188,13 +189,15 @@ def ContentTypeDiscriminatedBody(
     *,
     description: typing.Optional[str] = None,
 ) -> param_dependants.BodyBinderMarker:
-    extractor = ContentTypeDiscriminatedExtractorMarker()
-    openapi = OpenAPIContentTypeDiscriminatedMarker(
+    extractor = discriminated.BodyExtractorMarker()
+    openapi = discriminated.BodyOpenAPIMarker(
         description=description,
     )
     return param_dependants.BodyBinderMarker(
         extractor_marker=extractor,
+        field_extractor_marker=None,
         openapi_marker=openapi,
+        openapi_field_marker=None,
     )
 
 
