@@ -5,26 +5,21 @@ from pydantic import BaseModel
 from pydantic import ValidationError as PydanticValidationError
 from pydantic import create_model
 from pydantic.error_wrappers import ErrorWrapper
-from starlette.exceptions import HTTPException as StarletteHTTPException
+from starlette.exceptions import HTTPException
 from starlette.status import HTTP_422_UNPROCESSABLE_ENTITY
 
+__all__ = (
+    "XpressoError",
+    "HTTPException",
+    "RequestValidationError",
+    "WebSocketValidationError",
+)
+
 
 class XpressoError(Exception):
     ...
 
 
-# This should be upstreamed
-class HTTPException(StarletteHTTPException, XpressoError):
-    def __init__(
-        self,
-        status_code: int,
-        detail: typing.Any = None,
-        headers: typing.Optional[typing.Dict[str, str]] = None,
-    ) -> None:
-        super().__init__(status_code=status_code, detail=detail)
-        self.headers = headers or {}
-
-
 _RequestErrorModel: Type[BaseModel] = create_model("Request")  # type: ignore
 _WebSocketErrorModel: Type[BaseModel] = create_model("WebSocket")  # type: ignore
 
